@@ -555,7 +555,12 @@ class DimensionIndexSequence(DataElementSequence):
         --------
         >>> dimension_index = DimensionIndexSequence("SLIDE")
         >>> i = dimension_index.get_index_position("ReferencedSegmentNumber")
-        >>> segment_numbers = dimension_index[i]
+        >>> dimension_description = dimension_index[i]
+        >>> dimension_description
+        (0020, 9164) Dimension Organization UID          ...
+        (0020, 9165) Dimension Index Pointer             AT: (0062, 000b)
+        (0020, 9167) Functional Group Pointer            AT: (0062, 000a)
+        (0020, 9421) Dimension Description Label         LO: 'Segment Number'
 
         """
         indices = [
@@ -642,11 +647,24 @@ class DimensionIndexSequence(DataElementSequence):
 
         Examples
         --------
-        >>> dimension_index = DimensionIndexSequence("SLIDE")
-        >>> values = dimension_index.get_index_values(...)
+        >>> dimension_index = DimensionIndexSequence('SLIDE')
+        >>> plane_positions = [
+        ...     PlanePositionSequence('SLIDE', [10.0, 0.0, 0.0], [1, 1]),
+        ...     PlanePositionSequence('SLIDE', [30.0, 0.0, 0.0], [1, 2]),
+        ...     PlanePositionSequence('SLIDE', [50.0, 0.0, 0.0], [1, 3])
+        ... ]
+        >>> values, indices = dimension_index.get_index_values(plane_positions)
         >>> names = dimension_index.get_index_keywords()
+        >>> for name in names:
+        ...     print(name)
+        ColumnPositionInTotalImagePixelMatrix
+        RowPositionInTotalImagePixelMatrix
+        XOffsetInSlideCoordinateSystem
+        YOffsetInSlideCoordinateSystem
+        ZOffsetInSlideCoordinateSystem
         >>> index = names.index("XOffsetInSlideCoordinateSystem")
         >>> print(values[:, index])
+        [10. 30. 50.]
 
         """
         return [
