@@ -6,6 +6,7 @@ from highdicom.sr.content import (
     ImageRegion3D,
     LongitudinalTemporalOffsetFromEvent,
     SourceImageForMeasurement,
+    SourceImageForMeasurementGroup,
     SourceImageForSegmentation,
     SourceImageForRegion,
     SourceSeriesForSegmentation,
@@ -136,6 +137,7 @@ __all__ = [
     'ScoordContentItem',
     'Scoord3DContentItem',
     'SourceImageForMeasurement',
+    'SourceImageForMeasurementGroup',
     'SourceImageForSegmentation',
     'SourceImageForRegion',
     'SourceSeriesForSegmentation',
